@@ -29,7 +29,10 @@ function showSongInfo (data) {
     if (data.stream) {
         name = data.stream
     }
-    $('#modalname').html('<a href="#" onclick="return controls.showInfoPopup(\'' + data.track.uri + '\', \'\', mopidy);">' + name + '</span></a>')
+    if (name != undefined)
+      $('#modalname').html('<a href="#" onclick="return controls.showInfoPopup(\'' + data.track.uri + '\', \'\', mopidy);">' + name + '</span></a>')
+    else
+      $('#modalname').html('')
     if (!artistsHtml && data.stream) {
         $('#modaldetail').html(data.track.name)
     } else if (artistsHtml.length) {
@@ -38,6 +41,8 @@ function showSongInfo (data) {
         } else {
             $('#modaldetail').html(artistsHtml)
         }
+    } else {
+        $('#modaldetail').html('')
     }
     $("#page")[0].style.removeProperty('padding-bottom')
     $('#infoname').html(name)
@@ -49,6 +54,8 @@ function showSongInfo (data) {
         } else {
             $('#infodetail').html(artistsText)
         }
+    } else {
+        $('#infodetail').html('')
     }
 }
 
@@ -234,6 +241,8 @@ function findElementYPosition(obj) {
     }
 }
 
+
+
 function initSocketevents () {
     mopidy.on('state:online', function () {
         showOffline(false)
@@ -243,6 +252,7 @@ function initSocketevents () {
         controls.getUriSchemes().then(function () {
             controls.showFavourites()
         })
+        initMasterApi()
         library.getBrowseDir()
         library.getSearchSchemes(searchBlacklist, mopidy)
         showLoading(false)
@@ -364,6 +374,10 @@ function switchContent (divid, uri) {
         hash += '?' + uri
     }
     location.hash = '#' + hash
+    if (hash == 'current' || hash == 'playlists') {
+       setTimeout(scrollToCurrentTrack,100);
+    }
+
 }
 
 function setHeadline (site) {
@@ -386,14 +400,16 @@ function updateOptions () {
 
 // update everything as if reloaded
 function updateStatusOfAll () {
-    mopidy.playback.getCurrentTlTrack().then(processCurrenttrack, console.error)
-    mopidy.playback.getTimePosition().then(processCurrentposition, console.error)
-    mopidy.playback.getState().then(processPlaystate, console.error)
+    mopidy_connected().then(() => {
+      mopidy.playback.getCurrentTlTrack().then(processCurrenttrack, console.error)
+      mopidy.playback.getTimePosition().then(processCurrentposition, console.error)
+      mopidy.playback.getState().then(processPlaystate, console.error)
 
-    updateOptions()
+      updateOptions()
 
-    mopidy.mixer.getVolume().then(processVolume, console.error)
-    mopidy.mixer.getMute().then(processMute, console.error)
+      mopidy.mixer.getVolume().then(processVolume, console.error)
+      mopidy.mixer.getMute().then(processMute, console.error)
+   })
 }
 
 function locationHashChanged () {
@@ -460,6 +476,7 @@ function locationHashChanged () {
  * initialize software *
  ***********************/
 $(document).ready(function (event) {
+    setLocale()
     showOffline(true)
     // check for websockets
     if (!window.WebSocket) {
@@ -511,9 +528,9 @@ $(document).ready(function (event) {
     // event handlers for full screen mode
     $(document).on('webkitfullscreenchange mozfullscreenchange fullscreenchange, MSFullscreenChange', function (e) {
         if (isFullscreen()) {
-            document.getElementById('toggletxt').innerHTML = 'Exit Fullscreen'
+            document.getElementById('toggletxt').innerHTML = t('Exit Fullscreen')
         } else {
-            document.getElementById('toggletxt').innerHTML = 'Fullscreen'
+            document.getElementById('toggletxt').innerHTML = t('Fullscreen')
         }
     })
 
@@ -532,6 +549,11 @@ $(document).ready(function (event) {
         $('#homeAlarmClock').nextAll().find('.ui-block-a, .ui-block-b').toggleClass('ui-block-a').toggleClass('ui-block-b')
     }
 
+    // Remove Market icons if it is not present
+    if (!$(document.body).data('has-market')) {
+        $('#navMarket').hide()
+    }
+
     // navigation stuff
 
     $(document).keypress(function (event) {
@@ -600,7 +622,7 @@ $(document).ready(function (event) {
     if (websocketUrl) {
         connectOptions['webSocketUrl'] = websocketUrl
     }
-
+    currentWebsocketUrl = websocketUrl
     mopidy = new Mopidy(connectOptions)
     // initialize events
     initSocketevents()
@@ -624,6 +646,7 @@ function updatePlayIcons (uri, tlid, popupMenuIcon) {
             if (this.id === getjQueryID(target, uri) && eachTlid === tlid) {
                 if (!$(this).hasClass('currenttrack')) {
                     $(this).addClass('currenttrack')
+                    scrollToCurrentTrack();
                 }
             } else if ($(this).hasClass('currenttrack')) {
                 $(this).removeClass('currenttrack')
@@ -639,6 +662,7 @@ function updatePlayIcons (uri, tlid, popupMenuIcon) {
             if (uri) {
                 if (this.id === getjQueryID(target, uri)) {
                     $(this).addClass('currenttrack2')
+                    scrollToCurrentTrack();
                 } else {
                     $(this).removeClass('currenttrack2')
                 }
@@ -653,11 +677,7 @@ function updatePlayIcons (uri, tlid, popupMenuIcon) {
         })
     }
 
-    var current = $(".currenttrack")[0]
-    if (current != undefined) {
-      var currentPos = findElementYPosition($(".currenttrack")[0])
-      window.scroll(0,currentPos-100)
-    }
+
 }
 
 
