@@ -41,9 +41,15 @@ class DarkWebclient:
 
         return ws_url
 
+    def locale(self):
+        return self.ext_config.get("locale", "en")
+
     def has_alarm_clock(self):
         return self.config.get("alarmclock", {}).get("enabled", False)
 
+    def has_market(self):
+        return self.config.get("market", {}).get("enabled", False)
+
     def is_music_box(self):
         return self.ext_config.get("musicbox", False)
 
